@@ -109,8 +109,8 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
     }
 
     # Define palette
-    paletteBasic <- paletteDetector(c("white","black","purple","blue","darkgrey","red"));
-    ellipsis$col <- paletteBasic[2];
+    paletteBasic <- paletteDetector(c("black","red","purple","blue","darkgrey"));
+    ellipsis$col <- paletteBasic[1];
 
     legendCall <- list(x="bottom");
     if(length(level>1)){
@@ -121,12 +121,7 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
         legendCall$legend <- c("Series","Fitted values",pointForecastLabel,
                                paste0(level*100,"% prediction interval"),"Forecast origin");
     }
-    if(all(paletteBasic %in% c("white","black","purple","blue","darkgrey","red"))){
-        legendCall$col <- paletteBasic[-1];
-    }
-    else{
-        legendCall$col <- paletteBasic;
-    }
+    legendCall$col <- paletteBasic;
     legendCall$lwd <- c(1,2,2,3,2);
     legendCall$lty <- c(1,2,1,2,1);
     legendCall$ncol <- 3
@@ -230,11 +225,10 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
         else{
             par(mar=rep(0.1,4), bty="n", xaxt="n", yaxt="n")
         }
-        plot(0,0,col="white")
+        plot(0,0,col=0)
         legendDone <- do.call("legend", legendCall);
         rect(legendDone$rect$left-0.02, legendDone$rect$top-legendDone$rect$h,
              legendDone$rect$left+legendDone$rect$w+0.02, legendDone$rect$top);
-
     }
 
     if(parReset){
@@ -245,15 +239,8 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
     # }
     do.call(plot, ellipsis);
 
-    if(any(!is.na(fitted))){
-        lines(fitted, col=paletteBasic[3], lwd=2, lty=2);
-    }
-    else{
-        legendElements[2] <- FALSE;
-    }
-
     if(vline){
-        abline(v=time(forecast)[1]-deltat(forecast),col=paletteBasic[6],lwd=2);
+        abline(v=time(forecast)[1]-deltat(forecast),col=paletteBasic[2],lwd=2);
     }
 
     if(intervals){
@@ -264,7 +251,7 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
                     if(all(is.finite(upper[,i])) && all(is.finite(lower[,i]))){
                         polygon(c(time(upper[,i]),rev(time(lower[,i]))),
                                 c(as.vector(upper[,i]), rev(as.vector(lower[,i]))),
-                                col="lightgrey", border=NA, density=(ncol(lower)-i+1)*10);
+                                col=paletteBasic[5], border=NA, density=(ncol(lower)-i+1)*10);
                     }
                 }
             }
@@ -272,33 +259,33 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
             else if(is.matrix(lower) && is.matrix(upper) && ncol(lower)!=ncol(upper)){
                 polygon(c(time(upper[,ncol(upper)]),rev(time(lower[,ncol(lower)]))),
                         c(as.vector(upper[,ncol(upper)]), rev(as.vector(lower[,ncol(lower)]))),
-                        col="lightgrey", border=NA, density=10);
+                        col=paletteBasic[5], border=NA, density=10);
             }
             # If upper is not a matrix, use it as a vector
             else if(is.matrix(lower) && !is.matrix(upper)){
                 polygon(c(time(upper),rev(time(lower[,ncol(lower)]))),
                         c(as.vector(upper), rev(as.vector(lower[,ncol(lower)]))),
-                        col="lightgrey", border=NA, density=10);
+                        col=paletteBasic[5], border=NA, density=10);
             }
             # If lower is not a matrix, use it as a vector
             else if(!is.matrix(lower) && is.matrix(upper)){
                 polygon(c(time(upper[,ncol(upper)]),rev(time(lower))),
                         c(as.vector(upper[,ncol(upper)]), rev(as.vector(lower))),
-                        col="lightgrey", border=NA, density=10);
+                        col=paletteBasic[5], border=NA, density=10);
             }
             # Otherwise use both as vectors
             else{
                 if(all(is.finite(upper)) && all(is.finite(lower))){
                     polygon(c(time(upper),rev(time(lower))),
                             c(as.vector(upper), rev(as.vector(lower))),
-                            col="lightgrey", border=NA, density=10);
+                            col=paletteBasic[5], border=NA, density=10);
                 }
             }
 
 
             if(is.matrix(lower) || is.matrix(upper)){
                 nLevels <- max(ncol(lower), ncol(upper));
-                col <- colorRampPalette(paletteBasic[c(2,5)])(nLevels)[findInterval(1:nLevels,
+                col <- colorRampPalette(c(paletteBasic[c(4,5)]))(nLevels)[findInterval(1:nLevels,
                                                                                     seq(1, nLevels, length.out=nLevels))];
             }
             # Draw the lines
@@ -321,6 +308,7 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
             }
 
             lines(forecast,col=paletteBasic[4],lwd=2);
+            do.call("lines", ellipsis);
         }
         # Code for the h=1
         else{
@@ -344,7 +332,7 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
                 }
             }
             else{
-                points(upper,col=paletteBasic[5],lwd=3,pch=4);
+                points(upper,col=paletteBasic[4],lwd=3,pch=4);
             }
             points(forecast,col=paletteBasic[4],lwd=2,pch=4);
         }
@@ -357,10 +345,18 @@ graphmaker <- function(actuals, forecast, fitted=NULL, lower=NULL, upper=NULL,
             points(forecast,col=paletteBasic[4],lwd=2,pch=4);
         }
     }
+
+    if(any(!is.na(fitted))){
+        lines(fitted, col=paletteBasic[3], lwd=2, lty=2);
+    }
+    else{
+        legendElements[2] <- FALSE;
+    }
+
 }
 
 paletteDetector <- function(colours){
-    # If the default palette is used, define the new one in black and white
+    # If the default palette is used, define the new one in the provided colours
     paletteBasic <- palette();
     palette("default");
     paletteDefault <- palette();
